=============================================================
ORSim: Open Source Distributed Agent Based Simulation Library
=============================================================


.. image:: https://img.shields.io/pypi/v/orsim.svg
        :target: https://pypi.python.org/pypi/orsim

.. image:: https://readthedocs.org/projects/orsim/badge/?version=latest
        :target: https://orsim.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


ORSim is born out of a development Program called OpenRoad which is a set of libraries, tools and solvers to make research on Geo-Spatial problems Accessible.

OR in ORSim can refer to the Originating Project OpenRoad. It also refers to Operations Research and the Supporting Research lab IORA.


ORSim aims to be technology and platform Neutral even though the early versions are closely tied to other Open Source tech stacks such as RabbitMQ.


* Free software: MIT license
* Documentation: https://orsim.readthedocs.io.

Build & Upload Instructions
---------------------------
.. code-block:: console

        $ commit
        $ bumpversion [patch, minor, major]
        $ make dist
        $ twine upload dist/*


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
